==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/SectionHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { SectionHeaderDescription } from "./SectionHeaderDescription";
/**
 * @hidden
 */
export let SectionHeaderDescriptionMetadata = /*@__PURE__*/ (() => {
    class SectionHeaderDescriptionMetadata extends Base {
        static b(a) {
            if (SectionHeaderDescriptionMetadata.a == null) {
                SectionHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SectionHeaderDescriptionMetadata.c(SectionHeaderDescriptionMetadata.a);
            }
            if (a.k(SectionHeaderDescriptionMetadata.a)) {
                return;
            }
            a.ab(SectionHeaderDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
            a.item("SelectedBackground", "Brush");
            a.item("ActualSelectedBackground", "Brush");
            a.item("PaddingLeft", "Number:int");
            a.item("PaddingTop", "Number:int");
            a.item("PaddingRight", "Number:int");
            a.item("PaddingBottom", "Number:int");
            a.item("IsCollapsable", "Boolean");
            a.item("SummaryDisplayMode", "ExportedType:string:GroupSummaryDisplayMode");
            a.item("SummaryDisplayMode@names", "List;Cells;RowTop;RowBottom;None");
        }
        static d(a) {
            SectionHeaderDescriptionMetadata.b(a);
            a.ad("SectionHeader", () => new SectionHeaderDescription());
            a.ac("SectionHeader", SectionHeaderDescriptionMetadata.a);
        }
    }
    SectionHeaderDescriptionMetadata.$t = /*@__PURE__*/ markType(SectionHeaderDescriptionMetadata, 'SectionHeaderDescriptionMetadata');
    SectionHeaderDescriptionMetadata.a = null;
    return SectionHeaderDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/SectionHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { SectionHeaderDescription } from "./SectionHeaderDescription";
/**
 * @hidden
 */
export let SectionHeaderDescriptionMetadata = /*@__PURE__*/ (() => {
    class SectionHeaderDescriptionMetadata extends Base {
        static b(a) {
            if (SectionHeaderDescriptionMetadata.a == null) {
                SectionHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SectionHeaderDescriptionMetadata.c(SectionHeaderDescriptionMetadata.a);
            }
            if (a.k(SectionHeaderDescriptionMetadata.a)) {
                return;
            }
            a.ac(SectionHeaderDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
            a.item("SelectedBackground", "Brush");
            a.item("ActualSelectedBackground", "Brush");
            a.item("PaddingLeft", "Number:int");
            a.item("PaddingTop", "Number:int");
            a.item("PaddingRight", "Number:int");
            a.item("PaddingBottom", "Number:int");
            a.item("IsCollapsable", "Boolean");
            a.item("SummaryDisplayMode", "ExportedType:string:GroupSummaryDisplayMode");
            a.item("SummaryDisplayMode@names", "List;Cells;RowTop;RowBottom;None");
        }
        static d(a) {
            SectionHeaderDescriptionMetadata.b(a);
            a.ae("SectionHeader", () => new SectionHeaderDescription());
            a.ad("SectionHeader", SectionHeaderDescriptionMetadata.a);
        }
    }
    SectionHeaderDescriptionMetadata.$t = /*@__PURE__*/ markType(SectionHeaderDescriptionMetadata, 'SectionHeaderDescriptionMetadata');
    SectionHeaderDescriptionMetadata.a = null;
    return SectionHeaderDescriptionMetadata;
})();
